//
//  Business.swift
//  tfc
//
//  Created by jorge on 15/04/15.
//  Copyright (c) 2015 Jorge Tercero.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.
//

import Foundation
import CoreData

struct Business : Printable {

    // properties for business as a search result
    let name, slug: String
    let address, locality, telephone, summary, photoURL: String?
    let latitude, longitude: Double?

    
    var bigPhotoURL: String? {
        if let url = self.photoURL {
            return url.stringByReplacingOccurrencesOfString("so_", withString: "pxl_")
        } else {
            return nil
        }
    }
    
    init(slug: String, name: String, address: String?, locality: String?, telephone: String?, summary: String?, photoURL: String?, latitude: Double?, longitude: Double?) {
        self.slug = slug
        self.name = name
        self.address = address
        self.locality = locality
        self.telephone = telephone
        self.summary = summary
        self.photoURL = photoURL
        self.latitude = latitude
        self.longitude = longitude
    }
    
    init(biz: NSManagedObject) {
        self.name = biz.valueForKey("name") as! String
        self.slug = biz.valueForKey("slug") as! String
        self.address = biz.valueForKey("address") as? String
        self.locality = biz.valueForKey("locality") as? String
        self.photoURL = biz.valueForKey("photoURL") as? String
        self.summary = biz.valueForKey("summary") as? String
        self.telephone = biz.valueForKey("telephone") as? String
        self.latitude = biz.valueForKey("latitude") as? Double
        self.longitude = biz.valueForKey("longitude") as? Double
    }
    
    var description: String {
        return "\(slug) \(name) \(address) \(locality) \(telephone) \(photoURL)"
    }
    
    func hasCoordinates() -> Bool {
        return self.latitude != nil
            && self.latitude != 0.0
            && self.longitude != nil
            && self.longitude != 0.0
    }
}
