//
//  ViewController.swift
//  tfc
//
//  Created by jorge on 07/04/15.
//  Copyright (c) 2015 Jorge Tercero.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.
//

import UIKit
import CoreData

class HomeController: UIViewController, UISearchBarDelegate, SearchBusinessesDelegate, FeaturedBusinessDelegate {

    @IBOutlet weak var favoritesButton: UIButton!
    @IBOutlet weak var aroundMeButton: UIButton!
    
    @IBOutlet weak var searchBar: UISearchBar!
    var searchResults: [Business]?
    
    var suggestion1: Business?
    @IBOutlet weak var suggestion1Label: UILabel!
    @IBOutlet weak var suggestion1Photo: UIImageView!
    
    var suggestion2: Business?
    @IBOutlet weak var suggestion2Label: UILabel!
    @IBOutlet weak var suggestion2Photo: UIImageView!
    
    @IBAction func aroundMe(sender: UIButton) {
        let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        let localService = appDelegate.localService!
        localService.searchDelegate = self
        localService.aroundMe()
    }
    
    func searchBarSearchButtonClicked(searchBar: UISearchBar)
    {
        // obtenemos una referencia a LocalService (model)
        let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        let localService = appDelegate.localService!

        // nos registramos como delegate para recibir el resultado de búsqueda
        localService.searchDelegate = self

        // obtenemos la cadena de búsqueda de la serchBar, y la lanzamos al modelo
        localService.search(searchBar.text)
    }
    
    func locationReady() {
        // enable 'sitios cerca'
        self.aroundMeButton.enabled = true
        
        // load featured businesses
        let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        let localService = appDelegate.localService!
        localService.featuredBizDelegate = self
        localService.featuredBusiness()
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        searchBar.delegate = self
        
        NSNotificationCenter.defaultCenter().addObserver(self, selector:"locationReady", name: "TFCLocationReady", object: nil)
    }

    override func viewWillAppear(animated: Bool) {
        super.viewWillAppear(animated)
        
        self.favoritesButton.enabled = self.userHasFavorites()
    }

    func userHasFavorites() -> Bool {
        let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate
        let managedContext = appDelegate.managedObjectContext!
        
        let fetchRequest = NSFetchRequest(entityName:"Business")
        
        var error: NSError?
        let fetchedResults = managedContext.executeFetchRequest(fetchRequest, error: &error) as? [NSManagedObject]
        
        if let results = fetchedResults {
            return results.count>0
        } else {
            println("Could not fetch \(error), \(error!.userInfo)")
            return false
        }
    }
    
    // MARK: SearchBusinessDelegate
    
    func searchResults(results: [Business]) {
        self.searchResults = results
        // no podemos lanzar segues xq nos han llamado asíncronamente, trasladar al main thread
        dispatch_sync(dispatch_get_main_queue())
        {
            self.performSegueWithIdentifier("searchResults", sender: self)
        }
    }
    
    // MARK: FeaturedBusinessDelegate
    
    func featuredBusinessLoaded(results: [Business]) {
        self.suggestion1 = results[0]
        suggestion1Label.text = self.suggestion1!.name
        if let url = self.suggestion1!.bigPhotoURL {
            let data = NSData(contentsOfURL: NSURL(string:url)!)
            suggestion1Photo.image = UIImage(data: data!)
        } else {
            suggestion1Photo.image = UIImage(named: "grey_square")
        }

        self.suggestion2 = results[1]
        suggestion2Label.text = self.suggestion2!.name
        if let url = self.suggestion2!.bigPhotoURL {
            let data = NSData(contentsOfURL: NSURL(string:url)!)
            suggestion2Photo.image = UIImage(data: data!)
        } else {
            suggestion2Photo.image = UIImage(named: "grey_square")
        }
    }
    
    // MARK: navigation
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject!) {
        if (segue.identifier == "searchResults") {
            if let searchResultsController = segue.destinationViewController as? SearchResultsController {
                searchResultsController.results = self.searchResults;
            }
        } else if (segue.identifier == "showFeaturedBusiness1") {
            if let businessController = segue.destinationViewController as? BusinessController {
                businessController.biz = self.suggestion1;
            }
        } else if (segue.identifier == "showFeaturedBusiness2") {
            if let businessController = segue.destinationViewController as? BusinessController {
                businessController.biz = self.suggestion2;
            }
        }
    }
}

