//
//  OOSParser.swift
//  tfc
//
//  Created by jorge on 15/04/15.
//  Copyright (c) 2015 Jorge Tercero.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.
//

import Foundation

class OOSParser {
    
    func parseSearchResults(jsonSearchResults: NSData) -> [Business] {
        var results = [Business]()
        var parseError: NSError?
        let parsedObject: NSDictionary = NSJSONSerialization.JSONObjectWithData(
                jsonSearchResults,
            	options: NSJSONReadingOptions.AllowFragments,
                error:&parseError) as! NSDictionary
        
        let entries = parsedObject["entries"] as! NSArray
        for entry in entries {
            let biz = parseBusiness(entry as! NSDictionary)
            results.append(biz)
        }
        return results
    }
    
    func parseBusiness(entry: NSDictionary) -> Business {
        let name = entry["title"] as! String
        let summary = entry["summary"] as? String
        var slug: String = "slug"

        var address: String? = nil
        var locality: String? = nil
        var latitude: Double? = nil
        var longitude: Double? = nil
        
        var telephone: String? = nil
        var photoURL: String? = nil
        
        if let extensions = entry["extensions"] as? NSDictionary {
            slug = extensions["oos_slug"] as! String
            if let jsonaddress = extensions["oos_useraddress"] as? String {
                address = jsonaddress
            }
            if let jsonphone = extensions["oos_telephone"] as? String {
                telephone = jsonphone
            }
            if let jsonlocality = extensions["oos_locality"] as? NSDictionary {
                locality = (jsonlocality["name"] as! String)
            }
            if let georss = extensions["georss_where"] as? NSDictionary {
                if let gml_point = georss["gml_point"] as? NSDictionary {
                    let position = (gml_point["gml_pos"] as! String)
                    let pointArray = split(position) {$0 == " "}
                    latitude = (pointArray[0] as NSString).doubleValue
                    longitude = (pointArray[1] as NSString).doubleValue
                }
            }
        }
        if let links = entry["links"] as? NSArray {
            for link in links {
                if let rel = link["rel"] as? String {
                    if rel == "media" {
                        photoURL = link["href"] as? String
                    }
                }
            }
        }
        
        return Business(slug: slug, name: name, address: address, locality: locality, telephone: telephone, summary: summary, photoURL: photoURL, latitude: latitude, longitude: longitude)
    }
    
    func parseFeaturedBusiness(jsonBiz: NSData) -> [Business] {
        var results = [Business]()
        var parseError: NSError?
        let parsedObject: NSDictionary = NSJSONSerialization.JSONObjectWithData(
            jsonBiz,
            options: NSJSONReadingOptions.AllowFragments,
            error:&parseError) as! NSDictionary

        let entries = parsedObject["entries"] as! NSArray
        for entry in entries {
            let biz = parseBusiness(entry as! NSDictionary)
            results.append(biz)
        }
        return results
    }
    
    func parseBusinessReviews(jsonSearchResults: NSData) -> [Review] {
        var results = [Review]()
        var parseError: NSError?
        let parsedObject: NSDictionary = NSJSONSerialization.JSONObjectWithData(
            jsonSearchResults,
            options: NSJSONReadingOptions.AllowFragments,
            error:&parseError) as! NSDictionary
        
        let entries = parsedObject["entries"] as! NSArray
        for entry in entries {
            let review = parseReview(entry as! NSDictionary)
            results.append(review)
        }
        return results
    }
    
    func parseReview(entry: NSDictionary) -> Review {
        let title = entry["summary"] as? String
        var content: String? = nil
        var authorName: String? = nil
        var authorPhotoURL: String? = nil
        
        if let jsoncontent = entry["content"] as? NSDictionary {
            content = (jsoncontent["value"] as! String)
        }
        if let jsonauthor = entry["author"] as? NSDictionary {
            authorName = (jsonauthor["name"] as! String)
            if let jsonext = jsonauthor["extensions"] as? NSDictionary {
                authorPhotoURL = (jsonext["oos_avatar"] as! String)
            }
        }
        return Review(title: title, content: content, authorName: authorName, authorPhotoURL: authorPhotoURL)
    }
}